var UploadImageModel_1;
import { __decorate, __metadata } from "tslib";
import { remove } from 'fs-extra/esm';
import { join } from 'path';
import { AfterDestroy, AllowNull, BelongsTo, Column, CreatedAt, Default, ForeignKey, Table, UpdatedAt } from 'sequelize-typescript';
import { logger } from '../../helpers/logger.js';
import { DIRECTORIES, STATIC_PATHS, WEBSERVER } from '../../initializers/constants.js';
import { ActorModel } from '../actor/actor.js';
import { SequelizeModel } from '../shared/index.js';
let UploadImageModel = UploadImageModel_1 = class UploadImageModel extends SequelizeModel {
    static removeFile(instance) {
        logger.info('Removing upload image file %s.', instance.filename);
        instance.removeImage()
            .catch(err => logger.error('Cannot remove upload image file %s.', instance.filename, { err }));
    }
    static listByActor(actor) {
        const query = {
            where: {
                actorId: actor.id
            }
        };
        return UploadImageModel_1.findAll(query);
    }
    static listByActorAndType(actor, type, transaction) {
        const query = {
            where: {
                actorId: actor.id,
                type
            },
            transaction
        };
        return UploadImageModel_1.findAll(query);
    }
    static getImageUrl(image) {
        if (!image)
            return undefined;
        return WEBSERVER.URL + image.getStaticPath();
    }
    static getPathOf(filename) {
        return join(DIRECTORIES.UPLOAD_IMAGES, filename);
    }
    getStaticPath() {
        return join(STATIC_PATHS.UPLOAD_IMAGES, this.filename);
    }
    getPath() {
        return UploadImageModel_1.getPathOf(this.filename);
    }
    removeImage() {
        return remove(this.getPath());
    }
    isOwned() {
        return !this.fileUrl;
    }
};
__decorate([
    AllowNull(false),
    Column,
    __metadata("design:type", String)
], UploadImageModel.prototype, "filename", void 0);
__decorate([
    AllowNull(true),
    Default(null),
    Column,
    __metadata("design:type", Number)
], UploadImageModel.prototype, "height", void 0);
__decorate([
    AllowNull(true),
    Default(null),
    Column,
    __metadata("design:type", Number)
], UploadImageModel.prototype, "width", void 0);
__decorate([
    AllowNull(true),
    Column,
    __metadata("design:type", String)
], UploadImageModel.prototype, "fileUrl", void 0);
__decorate([
    AllowNull(false),
    Column,
    __metadata("design:type", Number)
], UploadImageModel.prototype, "type", void 0);
__decorate([
    CreatedAt,
    __metadata("design:type", Date)
], UploadImageModel.prototype, "createdAt", void 0);
__decorate([
    UpdatedAt,
    __metadata("design:type", Date)
], UploadImageModel.prototype, "updatedAt", void 0);
__decorate([
    ForeignKey(() => ActorModel),
    Column,
    __metadata("design:type", Number)
], UploadImageModel.prototype, "actorId", void 0);
__decorate([
    BelongsTo(() => ActorModel, {
        foreignKey: {
            allowNull: false
        },
        onDelete: 'CASCADE'
    }),
    __metadata("design:type", Object)
], UploadImageModel.prototype, "Actor", void 0);
__decorate([
    AfterDestroy,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [UploadImageModel]),
    __metadata("design:returntype", void 0)
], UploadImageModel, "removeFile", null);
UploadImageModel = UploadImageModel_1 = __decorate([
    Table({
        tableName: 'uploadImage',
        indexes: [
            {
                fields: ['filename'],
                unique: true
            },
            {
                fields: ['actorId', 'type', 'width'],
                unique: true
            }
        ]
    })
], UploadImageModel);
export { UploadImageModel };
//# sourceMappingURL=upload-image.js.map